# pîrebok (from Kurdish "witch") - a guided adversarial fuzzer


[![pypi](https://img.shields.io/pypi/v/pirebok.svg)](https://pypi.org/project/pirebok/)
[![python](https://img.shields.io/pypi/pyversions/pirebok.svg)](https://pypi.org/project/pirebok/)
[![Build Status](https://github.com/HappyHackingSpace/pirebok/actions/workflows/ci.yml/badge.svg)](https://github.com/HappyHackingSpace/pirebok/actions/workflows/ci.yml)
[![codecov](https://codecov.io/gh/HappyHackingSpace/pirebok/branch/main/graphs/badge.svg)](https://codecov.io/github/HappyHackingSpace/pirebok)



* Documentation: <https://happyhackingspace.github.io/pirebok>
* GitHub: <https://github.com/HappyHackingSpace/pirebok>
* PyPI: <https://pypi.org/project/pirebok/>
* Free software: MIT


## Features
- Random generic fuzzer w/ multiple transformers
- Random sql fuzzer w/ multiple transformers
- Guided random sql fuzzer w/ multiple transformers and [metamaska](https://github.com/HappyHackingSpace/metamaska)

## Credits
- [Cookiecutter](https://github.com/audreyr/cookiecutter)
- [waynerv/cookiecutter-pypackage](https://github.com/waynerv/cookiecutter-pypackage)
- [ML-based-WAF](https://github.com/vladan-stojnic/ML-based-WAF)
- [WAF-A-MoLE](https://github.com/AvalZ/WAF-A-MoLE)
